==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/SOURCEPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SOURCEPROMPTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SOURCEPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEPROMPT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTDESC" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SOURCEPROMPTID_Type", propOrder = {
    "sourceprompt",
    "promptdesc"
})
public class SOURCEPROMPTID_Type {

    @XmlElement(name = "SOURCEPROMPT")
    protected long sourceprompt;
    @XmlElement(name = "PROMPTDESC")
    protected String promptdesc;

    /**
     * Gets the value of the sourceprompt property.
     * 
     */
    public long getSOURCEPROMPT() {
        return sourceprompt;
    }

    /**
     * Sets the value of the sourceprompt property.
     * 
     */
    public void setSOURCEPROMPT(long value) {
        this.sourceprompt = value;
    }

    /**
     * Gets the value of the promptdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROMPTDESC() {
        return promptdesc;
    }

    /**
     * Sets the value of the promptdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROMPTDESC(String value) {
        this.promptdesc = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/SOURCEPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SOURCEPROMPTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SOURCEPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEPROMPT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROMPTDESC" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SOURCEPROMPTID_Type", propOrder = {
    "sourceprompt",
    "promptdesc"
})
public class SOURCEPROMPTID_Type {

    @XmlElement(name = "SOURCEPROMPT")
    protected long sourceprompt;
    @XmlElement(name = "PROMPTDESC")
    protected String promptdesc;

    /**
     * Obtient la valeur de la propriété sourceprompt.
     * 
     */
    public long getSOURCEPROMPT() {
        return sourceprompt;
    }

    /**
     * Définit la valeur de la propriété sourceprompt.
     * 
     */
    public void setSOURCEPROMPT(long value) {
        this.sourceprompt = value;
    }

    /**
     * Obtient la valeur de la propriété promptdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROMPTDESC() {
        return promptdesc;
    }

    /**
     * Définit la valeur de la propriété promptdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROMPTDESC(String value) {
        this.promptdesc = value;
    }

}
